@@ -7,12 +7,12 @@ import sys
 import warnings
 from pathlib import Path
 
-from pymatgen import Element
 from pymatgen.io.vasp.inputs import UnknownPotcarWarning
 from vise import __version__
 from vise.analyzer.atom_grouping_type import AtomGroupingType
 from vise.cli.main_functions import get_poscar_from_mp, VaspSet, plot_band, \
-    plot_dos, band_edge_properties, make_atom_poscars
+    plot_dos, band_edge_properties, plot_absorption, \
+    calc_effective_mass, structure_info
 from vise.defaults import defaults
 from vise.input_set.task import Task
 from vise.input_set.xc import Xc
@@ -25,17 +25,16 @@ logger = get_logger(__name__)
 warnings.simplefilter('ignore', UnknownPotcarWarning)
 
 
-def parse_args(args):
-    vise_yaml_files = '\n'.join(["* " + str(f) for f in defaults.yaml_files])
-    parser = argparse.ArgumentParser(
-        description=f"""
-Vise is a package that helps researchers to do first-principles calculations
-with the VASP code.
+description = """Vise is a package that helps researchers to
+to generate VASP input files for several tasks with suitable defaults, 
+and allows for tuning some parameters depending on their particular purposes."""
 
-Author: Yu Kumagai
-Version: {__version__}
-    """,
-        epilog=f"The parsed vise.yaml files are:\n{vise_yaml_files}",
+epilog = f"Author: Yu Kumagai Version: {__version__}"
+
+
+def parse_args(args):
+    parser = argparse.ArgumentParser(
+        description=description, epilog=epilog,
         formatter_class=argparse.RawTextHelpFormatter)
 
     subparsers = parser.add_subparsers()
@@ -51,45 +50,56 @@ Version: {__version__}
         "-o", "--outcar", type=Path, default=defaults.outcar,
         help="OUTCAR file name.")
 
+    # -- structure_info ---------------------------------------------------
+    parser_structure_info = subparsers.add_parser(
+        name="structure_info",
+        description="Shows structure info or conventional cell.",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        aliases=['si'])
+
+    parser_structure_info.add_argument(
+        "-p", "--poscar", type=str, default="POSCAR",
+        help="POSCAR-type file name to be read.", metavar="FILE")
+    parser_structure_info.add_argument(
+        "-s", "--symprec", type=float,
+        default=defaults.symmetry_length_tolerance,
+        help="Length tolerance in Å for symmetry analysis.")
+    parser_structure_info.add_argument(
+        "-a", "--angle_tolerance", type=float,
+        default=defaults.symmetry_angle_tolerance,
+        help="Angle tolerance in degree for symmetry analysis.")
+    parser_structure_info.add_argument(
+        "-c", "--show_conventional", action="store_true",
+        help="Describe the conventional cell.")
+    parser_structure_info.add_argument(
+        "-primitive", "--show_primitive", action="store_true",
+        help="Describe the primitive cell.")
+
+    parser_structure_info.set_defaults(func=structure_info)
+
     # -- get_poscar -----------------------------------------------------------
     parser_get_poscar = subparsers.add_parser(
         name="get_poscar",
-        description="Tools for generating a POSCAR file.",
+        description="Retrieves a POSCAR file from Materials Project Database.",
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         aliases=['gp'])
 
-    parser_get_poscar.add_argument(
-        "-p", "--poscar", type=str, default="POSCAR",
-        help="POSCAR-type file name.", metavar="FILE")
-    parser_get_poscar.add_argument(
-        "-pi", "--prior_info", type=Path, default=Path("prior_info.yaml"),
-        help="prior_info.yaml file name.", metavar="FILE")
     parser_get_poscar.add_argument(
         "-m", "--mpid", type=str, required=True,
         help="MP entry id with prefix, e.g., mp-1234.")
+    parser_get_poscar.add_argument(
+        "-p", "--poscar", type=str, default="POSCAR",
+        help="POSCAR-type file name to be written.", metavar="FILE")
+    parser_get_poscar.add_argument(
+        "-pi", "--prior_info", type=Path, default=Path("prior_info.yaml"),
+        help="prior_info.yaml file name to be written.", metavar="FILE")
 
     parser_get_poscar.set_defaults(func=get_poscar_from_mp)
 
-    # -- make_atom_poscars -----------------------------------------------------
-    parser_make_atom_poscars = subparsers.add_parser(
-        name="make_atom_poscars",
-        description="Tools for generating POSCAR files for atom calculations.",
-        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-        aliases=['map'])
-
-    parser_make_atom_poscars.add_argument(
-        "-d", "--dirname", type=Path, default=Path.cwd(),
-        help="Directory name where atom calculation directories are created.")
-    parser_make_atom_poscars.add_argument(
-        "-e", "--elements", type=Element, default=None, nargs="+",
-        help="Element names. When not set, all atom directories are created")
-
-    parser_make_atom_poscars.set_defaults(func=make_atom_poscars)
-
     # -- vasp_set ---------------------------------------------------------
     parser_vasp_set = subparsers.add_parser(
         name="vasp_set",
-        description="Tools for constructing vasp input set",
+        description="Constructs vasp input set",
         parents=[vasprun_parser, outcar_parser],
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         aliases=['vs'])
@@ -134,18 +144,18 @@ Version: {__version__}
         perpendicular direction. This mode is useful when calculating the 
         supercells. """)
     parser_vasp_set.add_argument(
-        "--file_transfer_type", type=str, nargs="+",
-        help="File transfer which is used with the prev_dir argument and can "
-             "be written with pairs of file names and transfer types of "
+        "--file_transfer", dest="file_transfer_type", type=str, nargs="+",
+        help="File transfer which is used along with the prev_dir argument and "
+             "can be written with pairs of file names and transfer types of "
              "m (move), c (copy) or l (link). An example is: "
-             "--file_transfer_type ../POSCAR c ../WAVECAR l ")
+             "--file_transfer_type POSCAR c WAVECAR l ")
 
     parser_vasp_set.set_defaults(func=VaspSet)
 
     # -- plot_band -------------------------------------------------------------
     parser_plot_band = subparsers.add_parser(
         name="plot_band",
-        description="Tools for plotting band structures",
+        description="Plots a band structure",
         parents=[vasprun_parser],
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         aliases=['pb'])
@@ -164,7 +174,7 @@ Version: {__version__}
     # -- plot_dos -----------------------------------------------------------
     parser_plot_dos = subparsers.add_parser(
         name="plot_dos",
-        description="Tools for plotting density of states",
+        description="Plots density of states",
         parents=[vasprun_parser, outcar_parser],
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         aliases=['pd'])
@@ -200,10 +210,54 @@ Version: {__version__}
         help="Set when showing the figure in the absolute energies scale.")
     parser_plot_dos.set_defaults(func=plot_dos)
 
+    # -- plot_absorption -------------------------------------------------------
+    parser_plot_absorption = subparsers.add_parser(
+        name="plot_absorption",
+        description="Plots optical absorption coefficient.",
+        parents=[vasprun_parser, outcar_parser],
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        aliases=['pa'])
+
+    parser_plot_absorption.add_argument(
+        "-f", "--filename", type=str, default="absorption.pdf",
+        help="Pdf file name.")
+    parser_plot_absorption.add_argument(
+        "-y", "--y_ranges", nargs="+", default=[10**3, 10**8],
+        type=lambda x: 10 ** float(x),
+        help="Exponential parts of base-10 for energy range in cm-1, "
+             "requiring two values.")
+    parser_plot_absorption.add_argument(
+        "-ckk", "--calc_kk", action="store_true",
+        help="Set when real part of dielectric function is explicitly "
+             "calculated using the Kramers-Kronig transformation.")
+    parser_plot_absorption.add_argument(
+        "-i", "--ita", type=float, default=0.01,
+        help="Complex shift η in the Kramers-Kronig transformation.")
+
+    parser_plot_absorption.set_defaults(func=plot_absorption)
+
+    # -- effective_mass -------------------------------------------------------
+    parser_effective_mass = subparsers.add_parser(
+        name="effective_mass",
+        description="Calculating effective masses via BoltzTrap2."
+                    "When using this, one needs to cite its paper(s).",
+        parents=[vasprun_parser, outcar_parser],
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        aliases=['em'])
+
+    parser_effective_mass.add_argument(
+        "-t", "--temperature", type=float, default=300,
+        help="Temperature in K.")
+    parser_effective_mass.add_argument(
+        "-c", "--concentrations", type=lambda x: 10 ** float(x), nargs="+",
+        help="Exponential parts of base-10 for concentrations in cm-3")
+
+    parser_effective_mass.set_defaults(func=calc_effective_mass)
+
     # -- band_edge -------------------------------------------------------------
     parser_band_edge = subparsers.add_parser(
         name="band_edge",
-        description="Calculate the band edge positions",
+        description="Calculates the band edge positions",
         parents=[vasprun_parser, outcar_parser],
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         aliases=['be'])
