@@ -3,12 +3,12 @@
 import json
 from dataclasses import dataclass, field
 from pathlib import Path
-from typing import Optional
+from typing import Optional, List
 
 import yaml
 from monty.json import MSONable
 from monty.serialization import loadfn
-from pymatgen import Structure
+from pymatgen.core import Structure
 from pymatgen.io.vasp import Vasprun, Outcar, Potcar
 from vise.analyzer.vasp.band_edge_properties import VaspBandEdgeProperties
 from vise.defaults import defaults
@@ -25,8 +25,7 @@ class PriorInfo(MSONable):
     data_source: str = None
     is_cluster: bool = None
     charge: int = None
-    magnetization_criterion: float = defaults.integer_criterion
-    band_gap_criterion: float = defaults.band_gap_criterion
+    icsd_ids: List[int] = None
     incar: dict = field(default_factory=dict)
 
     def dump_yaml(self, filename: str = "prior_info.yaml") -> None:
@@ -51,13 +50,13 @@ class PriorInfo(MSONable):
     @property
     def is_magnetic(self) -> Optional[bool]:
         try:
-            return self.total_magnetization > self.magnetization_criterion
+            return self.total_magnetization > defaults.integer_criterion
         except TypeError:
             return
 
     @property
     def has_band_gap(self) -> bool:
-        return self.band_gap > self.band_gap_criterion
+        return self.band_gap > defaults.band_gap_criterion
 
     @property
     def is_metal(self) -> bool:
@@ -90,7 +89,7 @@ def prior_info_from_calc_dir(prev_dir_path: Path,
                                       vasprun.parameters["NELECT"],
                                       potcar)
     structure = vasprun.final_structure.copy()
-    energy_per_atom = vasprun.final_energy / len(structure)
+    energy_per_atom = outcar.final_energy / len(structure)
     band_edge_property = VaspBandEdgeProperties(vasprun, outcar)
     total_magnetization = outcar.total_mag
 
