@@ -32,7 +32,7 @@ def test_incorrect_element_potcar_error():
 
 @pytest.fixture
 def key_candidates():
-    return ["ENCUT", "MAGMOM", "LWAVE"]
+    return ["ENCUT", "MAGMOM", "LWAVE", "EFIELD_PEAD"]
 
 
 def test_dict2list(key_candidates):
@@ -42,6 +42,13 @@ def test_dict2list(key_candidates):
     assert actual == expected
 
 
+def test_dict2list_2(key_candidates):
+    flattened_list = ["EFIELD_PEAD", "0.1", "0.1", "0.1"]
+    actual = list2dict(flattened_list, key_candidates)
+    expected = {"EFIELD_PEAD": [0.1, 0.1, 0.1]}
+    assert actual == expected
+
+
 def test_fail(key_candidates):
     flattened_list = ["ENCAT", "500"]
     with pytest.raises(ValueError):
@@ -52,3 +59,5 @@ def test_fail2(key_candidates):
     flattened_list = ["ENCUT", "500", "MAGMOM"]
     with pytest.raises(ValueError):
         list2dict(flattened_list, key_candidates)
+
+
