@@ -3,9 +3,9 @@ import json
 from pathlib import Path
 
 import pytest
-from monty.json import MSONable, MontyDecoder
-from pymatgen import Lattice
-from pymatgen.core.structure import Structure
+from pymatgen.core import Lattice
+from pymatgen.core.structure import Structure, IStructure
+from vise.util.structure_symmetrizer import StructureSymmetrizer
 
 
 @pytest.fixture(scope="session")
@@ -29,6 +29,12 @@ def mc_structure():
     return Structure(lattice=lattice, species=["H"], coords=coords)
 
 
+@pytest.fixture(scope="session")
+def mc_structure_conv(mc_structure):
+    symmetrizer = StructureSymmetrizer(mc_structure)
+    return symmetrizer.conventional
+
+
 @pytest.fixture(scope="session")
 def complex_monoclinic_structure():
     coords = [[0.0, 0.0, 0.0],
@@ -42,7 +48,8 @@ def complex_monoclinic_structure():
                      coords=coords)
 
 
-def assert_msonable(obj):
-    assert isinstance(obj, MSONable)
-    assert obj.as_dict() == obj.__class__.from_dict(obj.as_dict()).as_dict()
-    assert json.loads(obj.to_json(), cls=MontyDecoder)
\ No newline at end of file
+@pytest.fixture(scope="session")
+def simple_cubic():
+    lattice = Lattice.cubic(1.0)
+    coords = [[0.0, 0.0, 0.0]]
+    return IStructure(lattice=lattice, species=["H"], coords=coords)
