@@ -27,3 +27,7 @@ class ExtendedEnum(Enum):
     @classmethod
     def name_list(cls):
         return [e for e in cls]
+
+    @classmethod
+    def name_str_list(cls):
+        return [str(e) for e in cls]
\ No newline at end of file
